package com.ruoyi.cs.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.cs.mapper.CsExpireRemindMapper;
import com.ruoyi.cs.domain.CsExpireRemind;
import com.ruoyi.cs.service.ICsExpireRemindService;

import javax.annotation.Resource;

/**
 * 到期提醒Service业务层处理
 *
 * @author ruoyi
 * @date 2024-05-07
 */
@Service
public class CsExpireRemindServiceImpl implements ICsExpireRemindService
{
    @Resource
    private CsExpireRemindMapper csExpireRemindMapper;

    /**
     * 查询到期提醒
     *
     * @param remindId 到期提醒主键
     * @return 到期提醒
     */
    @Override
    public CsExpireRemind selectCsExpireRemindByRemindId(String remindId)
    {
        return csExpireRemindMapper.selectCsExpireRemindByRemindId(remindId);
    }

    /**
     * 查询到期提醒列表
     *
     * @param csExpireRemind 到期提醒
     * @return 到期提醒
     */
    @Override
    public List<CsExpireRemind> selectCsExpireRemindList(CsExpireRemind csExpireRemind)
    {
        return csExpireRemindMapper.selectCsExpireRemindList(csExpireRemind);
    }

    /**
     * 新增到期提醒
     *
     * @param csExpireRemind 到期提醒
     * @return 结果
     */
    @Override
    public int insertCsExpireRemind(CsExpireRemind csExpireRemind)
    {
        csExpireRemind.setCreateAt(DateUtils.getNowDate());
        csExpireRemind.setDelFlag("0");
        return csExpireRemindMapper.insertCsExpireRemind(csExpireRemind);
    }

    /**
     * 修改到期提醒
     *
     * @param csExpireRemind 到期提醒
     * @return 结果
     */
    @Override
    public int updateCsExpireRemind(CsExpireRemind csExpireRemind)
    {
        csExpireRemind.setUpdateAt(DateUtils.getNowDate());
        return csExpireRemindMapper.updateCsExpireRemind(csExpireRemind);
    }

    /**
     * 批量删除到期提醒
     *
     * @param remindIds 需要删除的到期提醒主键
     * @return 结果
     */
    @Override
    public int deleteCsExpireRemindByRemindIds(String[] remindIds)
    {
        return csExpireRemindMapper.deleteCsExpireRemindByRemindIds(remindIds);
    }

    /**
     * 删除到期提醒信息
     *
     * @param remindId 到期提醒主键
     * @return 结果
     */
    @Override
    public int deleteCsExpireRemindByRemindId(String remindId)
    {
        return csExpireRemindMapper.deleteCsExpireRemindByRemindId(remindId);
    }
}
